@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Copyright (C) 2007 Giampaolo Rodola' <g.rodola@gmail.com>.
 # Use of this source code is governed by MIT license that can be
@@ -8,9 +8,8 @@
 A basic ftpd storing passwords as hash digests (platform independent).
 """
 
-from hashlib import md5
+import hashlib
 import os
-import sys
 
 from pyftpdlib.authorizers import AuthenticationFailed
 from pyftpdlib.authorizers import DummyAuthorizer
@@ -21,11 +20,9 @@ from pyftpdlib.servers import FTPServer
 class DummyMD5Authorizer(DummyAuthorizer):
 
     def validate_authentication(self, username, password, handler):
-        if sys.version_info >= (3, 0):
-            password = md5(password.encode('latin1'))
-        hash = md5(password).hexdigest()
+        hash_ = hashlib.md5(password.encode('latin1')).hexdigest()
         try:
-            if self.user_table[username]['pwd'] != hash:
+            if self.user_table[username]['pwd'] != hash_:
                 raise KeyError
         except KeyError:
             raise AuthenticationFailed
@@ -33,9 +30,10 @@ class DummyMD5Authorizer(DummyAuthorizer):
 
 def main():
     # get a hash digest from a clear-text password
-    hash = md5(b'12345').hexdigest()
+    password = '12345'
+    hash_ = hashlib.md5(password.encode('latin1')).hexdigest()
     authorizer = DummyMD5Authorizer()
-    authorizer.add_user('user', hash, os.getcwd(), perm='elradfmwMT')
+    authorizer.add_user('user', hash_, os.getcwd(), perm='elradfmwMT')
     authorizer.add_anonymous(os.getcwd())
     handler = FTPHandler
     handler.authorizer = authorizer
