@@ -6,7 +6,7 @@
 
 """
 An RFC-4217 asynchronous FTPS server supporting both SSL and TLS.
-Requires PyOpenSSL module (http://pypi.python.org/pypi/pyOpenSSL).
+Requires PyOpenSSL module (https://pypi.org/project/pyOpenSSL).
 """
 
 import os
@@ -16,8 +16,9 @@ from pyftpdlib.handlers import TLS_FTPHandler
 from pyftpdlib.servers import FTPServer
 
 
-CERTFILE = os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                        "keycert.pem"))
+CERTFILE = os.path.abspath(
+    os.path.join(os.path.dirname(__file__), "keycert.pem")
+)
 
 
 def main():
