@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
-# Copyright (c) 2009 Giampaolo Rodola'. All rights reserved.
-# Use of this source code is governed by a BSD-style license that can be
+# Copyright (C) 2007 Giampaolo Rodola' <g.rodola@gmail.com>.
+# Use of this source code is governed by MIT license that can be
 # found in the LICENSE file.
 
 """
@@ -13,7 +13,7 @@ import subprocess
 
 
 SKIP_EXTS = ('.png', '.jpg', '.jpeg', '.svg')
-SKIP_FILES = ('appveyor.yml')
+SKIP_FILES = tuple()
 SKIP_PREFIXES = ('.ci/', '.github/')
 
 
@@ -24,9 +24,11 @@ def sh(cmd):
 def main():
     files = sh(["git", "ls-files"]).split('\n')
     for file in files:
-        if file.startswith(SKIP_PREFIXES) or \
-                os.path.splitext(file)[1].lower() in SKIP_EXTS or \
-                file in SKIP_FILES:
+        if (
+            file.startswith(SKIP_PREFIXES)
+            or os.path.splitext(file)[1].lower() in SKIP_EXTS
+            or file in SKIP_FILES
+        ):
             continue
         print("include " + file)
 
