@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
-# Copyright (c) 2009 Giampaolo Rodola'. All rights reserved.
-# Use of this source code is governed by a BSD-style license that can be
+# Copyright (C) 2007 Giampaolo Rodola' <g.rodola@gmail.com>.
+# Use of this source code is governed by MIT license that can be
 # found in the LICENSE file.
 
 """
@@ -19,10 +19,11 @@ HISTORY = os.path.abspath(os.path.join(HERE, '../../HISTORY.rst'))
 
 PRJ_NAME = 'pyftpdlib'
 PRJ_URL_HOME = 'https://github.com/giampaolo/pyftpdlib'
-PRJ_URL_DOC = 'http://pyftpdlib.readthedocs.io'
-PRJ_URL_DOWNLOAD = 'https://pypi.python.org/pypi/pyftpdlib'
-PRJ_URL_WHATSNEW = \
+PRJ_URL_DOC = 'https://pyftpdlib.readthedocs.io'
+PRJ_URL_DOWNLOAD = 'https://pypi.org/project/pyftpdlib'
+PRJ_URL_WHATSNEW = (
     'https://github.com/giampaolo/pyftpdlib/blob/master/HISTORY.rst'
+)
 
 template = """\
 Hello all,
@@ -70,13 +71,13 @@ def get_changes():
             break
     lines.pop(0)
 
-    for i, line in enumerate(lines):
+    while lines:
         line = lines.pop(0)
         line = line.rstrip()
         if re.match(r"^- \d+_: ", line):
             num, _, rest = line.partition(': ')
             num = ''.join([x for x in num if x.isdigit()])
-            line = "- #%s: %s" % (num, rest)
+            line = f"- #{num}: {rest}"
 
         if line.startswith('===='):
             break
@@ -92,15 +93,17 @@ def get_changes():
 
 def main():
     changes = get_changes()
-    print(template.format(
-        prj_name=PRJ_NAME,
-        prj_version=PRJ_VERSION,
-        prj_urlhome=PRJ_URL_HOME,
-        prj_urldownload=PRJ_URL_DOWNLOAD,
-        prj_urldoc=PRJ_URL_DOC,
-        prj_urlwhatsnew=PRJ_URL_WHATSNEW,
-        changes=changes,
-    ))
+    print(
+        template.format(
+            prj_name=PRJ_NAME,
+            prj_version=PRJ_VERSION,
+            prj_urlhome=PRJ_URL_HOME,
+            prj_urldownload=PRJ_URL_DOWNLOAD,
+            prj_urldoc=PRJ_URL_DOC,
+            prj_urlwhatsnew=PRJ_URL_WHATSNEW,
+            changes=changes,
+        )
+    )
 
 
 if __name__ == '__main__':
